# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_workspaces200_response_items_inner import GetWorkspaces200ResponseItemsInner

class TestGetWorkspaces200ResponseItemsInner(unittest.TestCase):
    """GetWorkspaces200ResponseItemsInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetWorkspaces200ResponseItemsInner:
        """Test GetWorkspaces200ResponseItemsInner
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetWorkspaces200ResponseItemsInner`
        """
        model = GetWorkspaces200ResponseItemsInner()
        if include_optional:
            return GetWorkspaces200ResponseItemsInner(
                id = '',
                name = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                member_count = 1.337
            )
        else:
            return GetWorkspaces200ResponseItemsInner(
                id = '',
                name = '',
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                member_count = 1.337,
        )
        """

    def testGetWorkspaces200ResponseItemsInner(self):
        """Test GetWorkspaces200ResponseItemsInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_panel_surveys200_response import GetPanelSurveys200Response

class TestGetPanelSurveys200Response(unittest.TestCase):
    """GetPanelSurveys200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetPanelSurveys200Response:
        """Test GetPanelSurveys200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetPanelSurveys200Response`
        """
        model = GetPanelSurveys200Response()
        if include_optional:
            return GetPanelSurveys200Response(
                items = [
                    keplar_api.models.admin_panel_invite.AdminPanelInvite(
                        id = '', 
                        name = '', 
                        code = '', 
                        status = 'PREVIEW', 
                        config = keplar_api.models.invite_config.InviteConfig(), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        project = keplar_api.models.admin_panel_invite_project.AdminPanelInvite_project(
                            id = '', 
                            name = '', 
                            created_by = keplar_api.models.admin_panel_invite_project_created_by.AdminPanelInvite_project_createdBy(
                                id = '', 
                                name = '', 
                                email = '', ), ), )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337
            )
        else:
            return GetPanelSurveys200Response(
                items = [
                    keplar_api.models.admin_panel_invite.AdminPanelInvite(
                        id = '', 
                        name = '', 
                        code = '', 
                        status = 'PREVIEW', 
                        config = keplar_api.models.invite_config.InviteConfig(), 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        project = keplar_api.models.admin_panel_invite_project.AdminPanelInvite_project(
                            id = '', 
                            name = '', 
                            created_by = keplar_api.models.admin_panel_invite_project_created_by.AdminPanelInvite_project_createdBy(
                                id = '', 
                                name = '', 
                                email = '', ), ), )
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337,
        )
        """

    def testGetPanelSurveys200Response(self):
        """Test GetPanelSurveys200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.get_projects200_response import GetProjects200Response

class TestGetProjects200Response(unittest.TestCase):
    """GetProjects200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GetProjects200Response:
        """Test GetProjects200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GetProjects200Response`
        """
        model = GetProjects200Response()
        if include_optional:
            return GetProjects200Response(
                items = [
                    keplar_api.models.project_summary_with_analytics.ProjectSummaryWithAnalytics()
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337
            )
        else:
            return GetProjects200Response(
                items = [
                    keplar_api.models.project_summary_with_analytics.ProjectSummaryWithAnalytics()
                    ],
                total = 1.337,
                page = 1.337,
                limit = 1.337,
        )
        """

    def testGetProjects200Response(self):
        """Test GetProjects200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class RepdataSurveyFieldDetails(BaseModel):
    """
    RepdataSurveyFieldDetails
    """ # noqa: E501
    cost: Optional[Union[StrictFloat, StrictInt]] = None
    abandons: Optional[Union[StrictFloat, StrictInt]] = None
    entrants: Optional[Union[StrictFloat, StrictInt]] = None
    inflight: Optional[Union[StrictFloat, StrictInt]] = None
    completes: Optional[Union[StrictFloat, StrictInt]] = None
    final_cost: Optional[Union[StrictFloat, StrictInt]] = None
    accepted_cost: Optional[Union[StrictFloat, StrictInt]] = None
    rejected_cost: Optional[Union[StrictFloat, StrictInt]] = None
    incidence_rate: Optional[Union[StrictFloat, StrictInt]] = None
    final_completes: Optional[Union[StrictFloat, StrictInt]] = None
    accepted_completes: Optional[Union[StrictFloat, StrictInt]] = None
    quality_terminates: Optional[Union[StrictFloat, StrictInt]] = None
    rejected_completes: Optional[Union[StrictFloat, StrictInt]] = None
    defender_terminates: Optional[Union[StrictFloat, StrictInt]] = None
    length_of_interview: Optional[Union[StrictFloat, StrictInt]] = None
    standard_terminates: Optional[Union[StrictFloat, StrictInt]] = None
    overquota_terminates: Optional[Union[StrictFloat, StrictInt]] = None
    accepted_unregistered_cost: Optional[Union[StrictFloat, StrictInt]] = None
    accepted_unregistered_completes: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["cost", "abandons", "entrants", "inflight", "completes", "final_cost", "accepted_cost", "rejected_cost", "incidence_rate", "final_completes", "accepted_completes", "quality_terminates", "rejected_completes", "defender_terminates", "length_of_interview", "standard_terminates", "overquota_terminates", "accepted_unregistered_cost", "accepted_unregistered_completes"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RepdataSurveyFieldDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if cost (nullable) is None
        # and model_fields_set contains the field
        if self.cost is None and "cost" in self.model_fields_set:
            _dict['cost'] = None

        # set to None if abandons (nullable) is None
        # and model_fields_set contains the field
        if self.abandons is None and "abandons" in self.model_fields_set:
            _dict['abandons'] = None

        # set to None if entrants (nullable) is None
        # and model_fields_set contains the field
        if self.entrants is None and "entrants" in self.model_fields_set:
            _dict['entrants'] = None

        # set to None if inflight (nullable) is None
        # and model_fields_set contains the field
        if self.inflight is None and "inflight" in self.model_fields_set:
            _dict['inflight'] = None

        # set to None if completes (nullable) is None
        # and model_fields_set contains the field
        if self.completes is None and "completes" in self.model_fields_set:
            _dict['completes'] = None

        # set to None if final_cost (nullable) is None
        # and model_fields_set contains the field
        if self.final_cost is None and "final_cost" in self.model_fields_set:
            _dict['final_cost'] = None

        # set to None if accepted_cost (nullable) is None
        # and model_fields_set contains the field
        if self.accepted_cost is None and "accepted_cost" in self.model_fields_set:
            _dict['accepted_cost'] = None

        # set to None if rejected_cost (nullable) is None
        # and model_fields_set contains the field
        if self.rejected_cost is None and "rejected_cost" in self.model_fields_set:
            _dict['rejected_cost'] = None

        # set to None if incidence_rate (nullable) is None
        # and model_fields_set contains the field
        if self.incidence_rate is None and "incidence_rate" in self.model_fields_set:
            _dict['incidence_rate'] = None

        # set to None if final_completes (nullable) is None
        # and model_fields_set contains the field
        if self.final_completes is None and "final_completes" in self.model_fields_set:
            _dict['final_completes'] = None

        # set to None if accepted_completes (nullable) is None
        # and model_fields_set contains the field
        if self.accepted_completes is None and "accepted_completes" in self.model_fields_set:
            _dict['accepted_completes'] = None

        # set to None if quality_terminates (nullable) is None
        # and model_fields_set contains the field
        if self.quality_terminates is None and "quality_terminates" in self.model_fields_set:
            _dict['quality_terminates'] = None

        # set to None if rejected_completes (nullable) is None
        # and model_fields_set contains the field
        if self.rejected_completes is None and "rejected_completes" in self.model_fields_set:
            _dict['rejected_completes'] = None

        # set to None if defender_terminates (nullable) is None
        # and model_fields_set contains the field
        if self.defender_terminates is None and "defender_terminates" in self.model_fields_set:
            _dict['defender_terminates'] = None

        # set to None if length_of_interview (nullable) is None
        # and model_fields_set contains the field
        if self.length_of_interview is None and "length_of_interview" in self.model_fields_set:
            _dict['length_of_interview'] = None

        # set to None if standard_terminates (nullable) is None
        # and model_fields_set contains the field
        if self.standard_terminates is None and "standard_terminates" in self.model_fields_set:
            _dict['standard_terminates'] = None

        # set to None if overquota_terminates (nullable) is None
        # and model_fields_set contains the field
        if self.overquota_terminates is None and "overquota_terminates" in self.model_fields_set:
            _dict['overquota_terminates'] = None

        # set to None if accepted_unregistered_cost (nullable) is None
        # and model_fields_set contains the field
        if self.accepted_unregistered_cost is None and "accepted_unregistered_cost" in self.model_fields_set:
            _dict['accepted_unregistered_cost'] = None

        # set to None if accepted_unregistered_completes (nullable) is None
        # and model_fields_set contains the field
        if self.accepted_unregistered_completes is None and "accepted_unregistered_completes" in self.model_fields_set:
            _dict['accepted_unregistered_completes'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RepdataSurveyFieldDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "cost": obj.get("cost"),
            "abandons": obj.get("abandons"),
            "entrants": obj.get("entrants"),
            "inflight": obj.get("inflight"),
            "completes": obj.get("completes"),
            "final_cost": obj.get("final_cost"),
            "accepted_cost": obj.get("accepted_cost"),
            "rejected_cost": obj.get("rejected_cost"),
            "incidence_rate": obj.get("incidence_rate"),
            "final_completes": obj.get("final_completes"),
            "accepted_completes": obj.get("accepted_completes"),
            "quality_terminates": obj.get("quality_terminates"),
            "rejected_completes": obj.get("rejected_completes"),
            "defender_terminates": obj.get("defender_terminates"),
            "length_of_interview": obj.get("length_of_interview"),
            "standard_terminates": obj.get("standard_terminates"),
            "overquota_terminates": obj.get("overquota_terminates"),
            "accepted_unregistered_cost": obj.get("accepted_unregistered_cost"),
            "accepted_unregistered_completes": obj.get("accepted_unregistered_completes")
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.vapi_assistant_config_artifact_plan import VapiAssistantConfigArtifactPlan

class TestVapiAssistantConfigArtifactPlan(unittest.TestCase):
    """VapiAssistantConfigArtifactPlan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VapiAssistantConfigArtifactPlan:
        """Test VapiAssistantConfigArtifactPlan
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VapiAssistantConfigArtifactPlan`
        """
        model = VapiAssistantConfigArtifactPlan()
        if include_optional:
            return VapiAssistantConfigArtifactPlan(
                recording_format = 'mp3',
                video_recording_enabled = True
            )
        else:
            return VapiAssistantConfigArtifactPlan(
        )
        """

    def testVapiAssistantConfigArtifactPlan(self):
        """Test VapiAssistantConfigArtifactPlan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.invite_response_with_metadata import InviteResponseWithMetadata

class TestInviteResponseWithMetadata(unittest.TestCase):
    """InviteResponseWithMetadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InviteResponseWithMetadata:
        """Test InviteResponseWithMetadata
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InviteResponseWithMetadata`
        """
        model = InviteResponseWithMetadata()
        if include_optional:
            return InviteResponseWithMetadata(
                id = '',
                attributes = [
                    keplar_api.models.invite_response_with_metadata_attributes_inner.InviteResponseWithMetadata_attributes_inner(
                        id = '', 
                        value = '', 
                        attribute_kind_id = '', 
                        evidence = keplar_api.models.invite_response_with_metadata_attributes_inner_evidence.InviteResponseWithMetadata_attributes_inner_evidence(
                            verbatims = '', 
                            confidence = 1.337, 
                            message_index = 1.337, ), )
                    ]
            )
        else:
            return InviteResponseWithMetadata(
                id = '',
                attributes = [
                    keplar_api.models.invite_response_with_metadata_attributes_inner.InviteResponseWithMetadata_attributes_inner(
                        id = '', 
                        value = '', 
                        attribute_kind_id = '', 
                        evidence = keplar_api.models.invite_response_with_metadata_attributes_inner_evidence.InviteResponseWithMetadata_attributes_inner_evidence(
                            verbatims = '', 
                            confidence = 1.337, 
                            message_index = 1.337, ), )
                    ],
        )
        """

    def testInviteResponseWithMetadata(self):
        """Test InviteResponseWithMetadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
